# pyqt-light-gray-theme
PyQt light-gray theme

This is deprecated except for my personal project. If you want to use light-gray style, use <a href="https://github.com/yjg30737/qtsasstheme.git">qtsasstheme</a>.
